@@ -25,7 +25,7 @@ Usage::
     list_simulation_jobs_paginator: ListSimulationJobsPaginator = client.get_paginator("list_simulation_jobs")
 """
 # pylint: disable=arguments-differ,redefined-outer-name,redefined-builtin
-from typing import Generator, List, TYPE_CHECKING
+from typing import Iterator, List, TYPE_CHECKING
 from botocore.paginate import Paginator as Boto3Paginator
 from mypy_boto3_robomaker.type_defs import (
     FilterTypeDef,
@@ -53,33 +53,33 @@ __all__ = (
 
 class ListDeploymentJobsPaginator(Boto3Paginator):
     """
-    [Paginator.ListDeploymentJobs documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.13/reference/services/robomaker.html#RoboMaker.Paginator.ListDeploymentJobs)
+    [Paginator.ListDeploymentJobs documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.14/reference/services/robomaker.html#RoboMaker.Paginator.ListDeploymentJobs)
     """
 
     def paginate(
         self, filters: List[FilterTypeDef] = None, PaginationConfig: PaginatorConfigTypeDef = None
-    ) -> Generator[ListDeploymentJobsResponseTypeDef, None, None]:
+    ) -> Iterator[ListDeploymentJobsResponseTypeDef]:
         """
-        [ListDeploymentJobs.paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.13/reference/services/robomaker.html#RoboMaker.Paginator.ListDeploymentJobs.paginate)
+        [ListDeploymentJobs.paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.14/reference/services/robomaker.html#RoboMaker.Paginator.ListDeploymentJobs.paginate)
         """
 
 
 class ListFleetsPaginator(Boto3Paginator):
     """
-    [Paginator.ListFleets documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.13/reference/services/robomaker.html#RoboMaker.Paginator.ListFleets)
+    [Paginator.ListFleets documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.14/reference/services/robomaker.html#RoboMaker.Paginator.ListFleets)
     """
 
     def paginate(
         self, filters: List[FilterTypeDef] = None, PaginationConfig: PaginatorConfigTypeDef = None
-    ) -> Generator[ListFleetsResponseTypeDef, None, None]:
+    ) -> Iterator[ListFleetsResponseTypeDef]:
         """
-        [ListFleets.paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.13/reference/services/robomaker.html#RoboMaker.Paginator.ListFleets.paginate)
+        [ListFleets.paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.14/reference/services/robomaker.html#RoboMaker.Paginator.ListFleets.paginate)
         """
 
 
 class ListRobotApplicationsPaginator(Boto3Paginator):
     """
-    [Paginator.ListRobotApplications documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.13/reference/services/robomaker.html#RoboMaker.Paginator.ListRobotApplications)
+    [Paginator.ListRobotApplications documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.14/reference/services/robomaker.html#RoboMaker.Paginator.ListRobotApplications)
     """
 
     def paginate(
@@ -87,28 +87,28 @@ class ListRobotApplicationsPaginator(Boto3Paginator):
         versionQualifier: str = None,
         filters: List[FilterTypeDef] = None,
         PaginationConfig: PaginatorConfigTypeDef = None,
-    ) -> Generator[ListRobotApplicationsResponseTypeDef, None, None]:
+    ) -> Iterator[ListRobotApplicationsResponseTypeDef]:
         """
-        [ListRobotApplications.paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.13/reference/services/robomaker.html#RoboMaker.Paginator.ListRobotApplications.paginate)
+        [ListRobotApplications.paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.14/reference/services/robomaker.html#RoboMaker.Paginator.ListRobotApplications.paginate)
         """
 
 
 class ListRobotsPaginator(Boto3Paginator):
     """
-    [Paginator.ListRobots documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.13/reference/services/robomaker.html#RoboMaker.Paginator.ListRobots)
+    [Paginator.ListRobots documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.14/reference/services/robomaker.html#RoboMaker.Paginator.ListRobots)
     """
 
     def paginate(
         self, filters: List[FilterTypeDef] = None, PaginationConfig: PaginatorConfigTypeDef = None
-    ) -> Generator[ListRobotsResponseTypeDef, None, None]:
+    ) -> Iterator[ListRobotsResponseTypeDef]:
         """
-        [ListRobots.paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.13/reference/services/robomaker.html#RoboMaker.Paginator.ListRobots.paginate)
+        [ListRobots.paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.14/reference/services/robomaker.html#RoboMaker.Paginator.ListRobots.paginate)
         """
 
 
 class ListSimulationApplicationsPaginator(Boto3Paginator):
     """
-    [Paginator.ListSimulationApplications documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.13/reference/services/robomaker.html#RoboMaker.Paginator.ListSimulationApplications)
+    [Paginator.ListSimulationApplications documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.14/reference/services/robomaker.html#RoboMaker.Paginator.ListSimulationApplications)
     """
 
     def paginate(
@@ -116,33 +116,33 @@ class ListSimulationApplicationsPaginator(Boto3Paginator):
         versionQualifier: str = None,
         filters: List[FilterTypeDef] = None,
         PaginationConfig: PaginatorConfigTypeDef = None,
-    ) -> Generator[ListSimulationApplicationsResponseTypeDef, None, None]:
+    ) -> Iterator[ListSimulationApplicationsResponseTypeDef]:
         """
-        [ListSimulationApplications.paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.13/reference/services/robomaker.html#RoboMaker.Paginator.ListSimulationApplications.paginate)
+        [ListSimulationApplications.paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.14/reference/services/robomaker.html#RoboMaker.Paginator.ListSimulationApplications.paginate)
         """
 
 
 class ListSimulationJobBatchesPaginator(Boto3Paginator):
     """
-    [Paginator.ListSimulationJobBatches documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.13/reference/services/robomaker.html#RoboMaker.Paginator.ListSimulationJobBatches)
+    [Paginator.ListSimulationJobBatches documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.14/reference/services/robomaker.html#RoboMaker.Paginator.ListSimulationJobBatches)
     """
 
     def paginate(
         self, filters: List[FilterTypeDef] = None, PaginationConfig: PaginatorConfigTypeDef = None
-    ) -> Generator[ListSimulationJobBatchesResponseTypeDef, None, None]:
+    ) -> Iterator[ListSimulationJobBatchesResponseTypeDef]:
         """
-        [ListSimulationJobBatches.paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.13/reference/services/robomaker.html#RoboMaker.Paginator.ListSimulationJobBatches.paginate)
+        [ListSimulationJobBatches.paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.14/reference/services/robomaker.html#RoboMaker.Paginator.ListSimulationJobBatches.paginate)
         """
 
 
 class ListSimulationJobsPaginator(Boto3Paginator):
     """
-    [Paginator.ListSimulationJobs documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.13/reference/services/robomaker.html#RoboMaker.Paginator.ListSimulationJobs)
+    [Paginator.ListSimulationJobs documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.14/reference/services/robomaker.html#RoboMaker.Paginator.ListSimulationJobs)
     """
 
     def paginate(
         self, filters: List[FilterTypeDef] = None, PaginationConfig: PaginatorConfigTypeDef = None
-    ) -> Generator[ListSimulationJobsResponseTypeDef, None, None]:
+    ) -> Iterator[ListSimulationJobsResponseTypeDef]:
         """
-        [ListSimulationJobs.paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.13/reference/services/robomaker.html#RoboMaker.Paginator.ListSimulationJobs.paginate)
+        [ListSimulationJobs.paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.14/reference/services/robomaker.html#RoboMaker.Paginator.ListSimulationJobs.paginate)
         """
